@@ -8,38 +8,38 @@ use std::{
 pub mod deps {}
 
 /// Returns a string describing the specific operating system in use.
-/// `nstd_std_os_free_name` must be called to free memory allocated by this function.
+/// `nstd_os_free_name` must be called to free memory allocated by this function.
 /// Returns: `char *os_name` - The os's name as a string.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_os_name() -> *mut c_char {
+pub unsafe extern "C" fn nstd_os_name() -> *mut c_char {
     static_nstd_create_cstr(OS)
 }
 
-/// Frees memory allocated by `nstd_std_os_name`.
+/// Frees memory allocated by `nstd_os_name`.
 /// Parameters:
 ///     `const char **os_name` - Pointer to the os name cstr.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_os_free_name(os_name: *mut *mut c_char) {
+pub unsafe extern "C" fn nstd_os_free_name(os_name: *mut *mut c_char) {
     static_nstd_deallocate_cstr(os_name);
 }
 
 /// Returns a string describing the specific cpu architecture in use.
-/// `nstd_std_os_free_arch_name` must be called to free memory allocated by this function.
+/// `nstd_os_free_arch_name` must be called to free memory allocated by this function.
 /// Returns: `char *arch_name` - The cpu architecture's name as a string.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_os_arch_name() -> *mut c_char {
+pub unsafe extern "C" fn nstd_os_arch_name() -> *mut c_char {
     static_nstd_create_cstr(ARCH)
 }
 
-/// Frees memory allocated by `nstd_std_os_arch_name`.
+/// Frees memory allocated by `nstd_os_arch_name`.
 /// Parameters:
 ///     `const char **arch_name` - Pointer to the arch name cstr.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_os_free_arch_name(arch_name: *mut *mut c_char) {
+pub unsafe extern "C" fn nstd_os_free_arch_name(arch_name: *mut *mut c_char) {
     static_nstd_deallocate_cstr(arch_name);
 }
 
